# __all__ = [
#     'MonobankAPIException',
#     'MonoPayAPIException'
# ]

from dataclasses import dataclass


class MonobankOpenAPIException(Exception):
    error_description: str = ""


class TooManyRequestsException(MonobankOpenAPIException):
    error_description: str = "MonobankException: Too many requests"


@dataclass
class MonobankAPIException:
    err_description: str = None


@dataclass
class MonoPayAPIException:
    err_code: str = None
    err_text: str = None
    error_description: str = None


class MonobankBadRequest(MonobankOpenAPIException):
    pass



__all__ = [
    'MonoAcquiringAPI',
    'MonobankOpenAPI',
    'MonobankCorporateOpenAPI'
]

from mbnk.api import (
    MonoAcquiringAPIModel,
    MonobankOpenAPIModel,
    MonobankCorporateOpenAPIModel
)


class MonoAcquiringAPI(MonoAcquiringAPIModel):
    """
    Synchronous version MonoAcquiringAPI
    Source: https://api.monobank.ua/docs/acquiring.html
    """

    def __init__(self, api_token: str):
        super().__init__(api_token=api_token, _async=False)


class MonobankOpenAPI(MonobankOpenAPIModel):
    """
    Synchronous version MonobankOpenAPI
    Source: https://api.monobank.ua/docs/
    """

    def __init__(self, api_token: str):
        super().__init__(api_token=api_token, _async=False)


class MonobankCorporateOpenAPI(MonobankCorporateOpenAPIModel):
    """
    Synchronous version MonobankCorporateOpenAPI
    Source: https://api.monobank.ua/docs/corporate.html
    """

    def __init__(self, api_token: str):
        super().__init__(api_token=api_token, _async=False)



__all__ = [
    'AsyncMonoAcquiringAPI',
    'AsyncMonobankOpenAPI',
    'AsyncMonobankCorporateOpenAPI'
]

from mbnk.api import (
    MonoAcquiringAPIModel,
    MonobankOpenAPIModel,
    MonobankCorporateOpenAPIModel
)


class AsyncMonoAcquiringAPI(MonoAcquiringAPIModel):
    """
    Asynchronous version MonoAcquiringAPI
    Source: https://api.monobank.ua/docs/acquiring.html
    """

    def __init__(self, api_token: str):
        super().__init__(api_token=api_token, _async=True)


class AsyncMonobankOpenAPI(MonobankOpenAPIModel):
    """
    Asynchronous version MonobankOpenAPI
    Source: https://api.monobank.ua/docs/
    """

    def __init__(self, api_token: str):
        super().__init__(api_token=api_token, _async=True)


class AsyncMonobankCorporateOpenAPI(MonobankCorporateOpenAPIModel):
    """
    Asynchronous version MonobankCorporateOpenAPI
    Source: https://api.monobank.ua/docs/corporate.html
    """

    def __init__(self, api_token: str):
        super().__init__(api_token=api_token, _async=True)
